import axios from "axios";
import semver from "semver";

export default async function ({siteVersion, projectId}) {
  if (siteVersion === 'next') {
    return 'latest'
  } else {
    return axios.get(`https://git.fitko.de/api/v4/projects/${projectId}/repository/tags`)
      .catch((error) => {
        throw `Fetching of latest tags failed with ${error.response.status}`
      })
      .then(async ({data}) => {
        const versionRange = `~${siteVersion}`
        const suitableVersions = await data
          .filter(({name}) => semver.satisfies(name, versionRange))
          .map(({name}) => name)
          .sort()

        return semver.maxSatisfying(suitableVersions, versionRange)
      })
  }
}
